@@ -178,13 +178,37 @@ def otf_calc(pup_fun, T, D, f, wvl):
     a, a, otf = np.abs(ifft2(P * P, 1))
     xx, yy = meshgrid(linspace(-1/2, 1/2, pup_fun.shape[0]))
     scaling = 2*D/T * f_cutoff
-    return xx/scaling, yy/scaling, otf/np.amax(otf)
+    return xx*scaling, yy*scaling, otf/np.amax(otf)
 
 
 def zern_phase_rep(phase, num_zern=36):
     print('hi')
 
 
+def gen_rand_vec(R, n_samp, mu=0, mode='chol'):
+    """
+    Generating a random vector according to an covariance matrix.
+
+    :param R: ndarray
+        Covariance matrix
+    :param n_samp: int
+        Number of samples desired
+    :param mu: float
+        Mean value of the random vector
+    :param mode: {'chol', 'eig'}
+        Different generation approaches, Cholesky by default
+    :return: the n_samp desired random vectors
+    """
+
+    if mode == 'chol':
+        L = np.linalg.cholesky(R)
+        return L @ np.random.randn(R.shape[1], n_samp) + mu
+    if mode == 'eig':
+        vals, vecs = np.linalg.eig(R)
+        print(vecs)
+        return (vecs @ np.diag(np.sqrt(vals))) @ np.random.randn(R.shape[1], n_samp) + mu
+
+
 def defocus_abgen(norm_grid, L_true, L_selected, wvl=500e-9):
     '''
     A function that returns a defocus (difference of spheres) aberration in radians.
